<?php

if (function_exists('acf_add_options_page')) {

    acf_add_options_page([
        'page_title' => 'Configuraciones Generales',
        'menu_title' => 'Configuración General',
        'menu_slug'  => 'general-settings',
        'capability' => 'edit_posts',
        'redirect'   => true
    ]);

}



/*=========== Add template in page list dashboard ===========*/

/**
 * 
 * Adds a Column to WordPress pages admin so you can easily see
 * which pages are using which page template.
 * 
 * @since 1.0
 */
function la_modify_page_table ( $columns ) {

  /* Add a Page Template Column */

  $custom_columns = array(
    'template' => __('Page Template', 'wordpress')
  );

  $columns = array_merge( $columns, $custom_columns );

  unset($columns['comments']);

  return $columns;
}

add_filter('manage_pages_columns', 'la_modify_page_table');

/**
 * Register our column as sortable
 */
function la_sortable_template_column($columns) {
  return array_merge( $columns, array( 'template' => 'template' ) );
}

add_filter('manage_edit-page_sortable_columns', 'la_sortable_template_column');

/*
 * Template column
 */
function la_template_column_orderby( $query ) {

  if (!is_admin()) return;

  $orderby = $query->get('orderby');

  if ( $orderby == 'template' ) {
    $query->set('meta_key', '_wp_page_template');
    $query->set('orderby', 'meta_value');
  }
}

add_action('pre_get_posts', 'la_template_column_orderby');



add_action( 'manage_pages_custom_column', 'page_custom_column_views', 5, 2 );
function page_custom_column_views( $column_name, $id )
{
   if ( $column_name === 'template' ) {
       $set_template = get_post_meta( get_the_ID(), '_wp_page_template', true );
       if ( $set_template == 'default' ) {
           echo 'Template predeterminada';
       }
       $templates = get_page_templates();
       ksort( $templates );
       foreach ( array_keys( $templates ) as $template ) :
           if ( $set_template == $templates[$template] ) echo $template;
       endforeach;
   }
}



add_filter( 'gform_display_add_form_button', 'display_form_button_on_custom_page' );
function display_form_button_on_custom_page( $is_post_edit_page ) {
    if ( isset( $_GET['page'] ) && $_GET['page'] == 'general-settings' ) {
        return true;
    }
 
    return $is_post_edit_page;
}




/*======= Cambiar URL del CPT Carreras para que incluya el Área ===========*/


function change_link( $post_link, $id = 0 ) {
    $post = get_post( $id );
    if( $post->post_type == 'carreras' ) 
    {
       if ( is_object( $post ) ) {
          $terms = wp_get_object_terms( $post->ID, array('area') );
          if ( $terms ) {
             return str_replace( '%area%', $terms[0]->slug, $post_link );
         }
      }
    }
    return   $post_link ;
}
add_filter( 'post_type_link', 'change_link', 1, 3 );

function generated_rewrite_rules() {
   add_rewrite_rule(
       '^carreras/(.*)/(.*)/?$',
       'index.php?post_type=carreras&name=$matches[2]',
       'top'
   );
}
add_action( 'init', 'generated_rewrite_rules' );

