<?php

use Themosis\Support\Facades\Action;
use Themosis\Support\Facades\Filter;

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 *
 * @return array
 */
Filter::add('body_class', function ($classes) {
    // Adds a class of hfeed to non-singular pages.
    if (! is_singular()) {
        $classes[] = 'hfeed';
    }

    // Adds a class of no-sidebar when there is no sidebar present.
    if (! is_active_sidebar('sidebar-1')) {
        $classes[] = 'no-sidebar';
    }

    return $classes;
});

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
Action::add('wp_head', function () {
    if (is_singular() && pings_open()) {
        echo '<link rel="pingback" href="'.esc_url(get_bloginfo('pingback_url')).'">';
    }
});

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 */
Action::add('after_setup_theme', function () {
    $GLOBALS['content_width'] = 640;
}, 0);



Filter::add('acf/settings/save_json', function () {
    // update path
    $path = get_stylesheet_directory() . '/acf-json';

    return $path;
});
Filter::add('acf/settings/load_json', function ($paths) {
    unset($paths[0]);
    $paths[] = get_stylesheet_directory() . '/acf-json';
    return $paths;
});


Filter::add('wp_enqueue_scripts', function (){
   wp_enqueue_script('jquery', false, array(), false, false);
});

Filter::add('gform_init_scripts_footer', function (){
    return true;
});



/**
 *  Remove the h1 tag from the WordPress editor.
 *
 *  @param   array  $settings  The array of editor settings
 *  @return  array             The modified edit settings
 */
function remove_h1_from_editor( $settings ) {
    $settings['block_formats'] = 'Paragraph=p;Heading 2=h2;Heading 3=h3;Heading 4=h4;Heading 5=h5;Heading 6=h6;Preformatted=pre;';
    return $settings;
}
add_filter( 'tiny_mce_before_init', 'remove_h1_from_editor' );





function get_page_id_by_template($template)
{
    $args = array(
        'post_type'        => 'page',
        'fields'           => 'ids',
        'nopaging'         => true,
        'meta_key'         => '_wp_page_template',
        'meta_value'       => $template,
        'suppress_filters' => 0
    );
    $pages = get_posts($args);
    if ($pages) {
        return $pages[0];
    } else return 0;
}



/* Nav Menu - Class for <li> & <a>  */
function wpdocs_special_nav_class( $classes, $item ) {
    $classes[] = "nav-item";
    return $classes;
}
add_filter( 'nav_menu_css_class' , 'wpdocs_special_nav_class' , 10, 2 );



function add_class_to_all_menu_anchors( $atts ) {
    $atts['class'] = 'nav-link admision-menu-superior';
    return $atts;
}
add_filter( 'nav_menu_link_attributes', 'add_class_to_all_menu_anchors', 10 );



