<?php

namespace Theme\Helpers;

use Theme\Models\Career;
use Theme\Models\Area;
use Theme\Models\Pregunta;
use Theme\Models\Tema;


class Helper
{
    
    static function getCarrerasByArea($area)
    {
        $_posts = [];
        $posts = get_posts([
            'post_type'      => 'carreras',
            'status'         => 'publish',
            'orderby'        => 'title',
            'order'          => 'ASC',
            'posts_per_page' => -1,
            'tax_query' => array(
                array(
                    'taxonomy' => 'area',
                    'field'    => 'slug',
                    'terms'    => array( $area ),
                ),
            )        
        ]);
        
        foreach ($posts as $post) {
            $_posts[] = new Career($post);
        }

        return $_posts;
        
    }


    static function getCarrerasBySede($sede = '')
    {
        $_posts = [];
        if($sede != ''){
          $posts = get_posts([
            'post_type'      => 'carreras',
            'status'         => 'publish',
            'orderby'        => 'title',
            'order'          => 'ASC',
            'posts_per_page' => -1,
            'tax_query' => array(
                array(
                    'taxonomy' => 'sede',
                    'field'    => 'slug',
                    'terms'    => array( $sede ),
                ),
            )        
          ]);

        }else{

          $posts = get_posts([
            'post_type'      => 'carreras',
            'status'         => 'publish',
            'orderby'        => 'title',
            'order'          => 'ASC',
            'posts_per_page' => -1,  
          ]);

        }

        foreach ($posts as $post) {
            $_posts[] = new Career($post);
        }
        return $_posts;
        
    }


    static function getCarrerasByAreaAndSede($slug_area, $slug_sede )
    {
        $_posts = [];
        $posts = get_posts([
            'post_type'      => 'carreras',
            'status'         => 'publish',
            'orderby'        => 'title',
            'order'          => 'ASC',
            'posts_per_page' => -1,
            'tax_query' => array(
                'relation' => 'AND',
                array(
                    'taxonomy' => 'area',
                    'field'    => 'slug',
                    'terms'    => array( $slug_area ),
                ),
                array(
                    'taxonomy' => 'sede',
                    'field'    => 'slug',
                    'terms'    => array( $slug_sede ),
                ),
            )        
        ]);
        
        foreach ($posts as $post) {
            $_posts[] = new Career($post);
        }

        return $_posts;
        
    }


    static function getSedes(){
      $terms = get_terms( array(
          'taxonomy' => 'sede',
          'hide_empty' => true,
          'orderby' => 'name',
          'order' => 'ASC',
          'posts_per_page' => -1,
      ) );

      return $terms;

    }

    static function getAreas(){
      $terms = get_terms( array(
          'taxonomy' => 'area',
          'hide_empty' => true,
          'orderby' => 'name',
          'order' => 'ASC',
          'posts_per_page' => -1,
      ) );

      return $terms;

    }


    static function getAreasBySede($sede){

      $carreras = self::getCarrerasBySede($sede);
      $itemsArray = array();

      foreach ($carreras as $key => $carrera) {
        $itemsArray[] = $carrera->getArea()->slug;
      }

      $terms = get_terms( array(
          'taxonomy' => 'area',
          'hide_empty' => true,
          'slug' => $itemsArray,
          'orderby' => 'name',
          'order' => 'ASC',
          'posts_per_page' => -1,
      ) );

      return $terms;

    }


    static function getIDPaginaCalendario(){
      
      $args = [
        'post_type' => 'page',
        'fields' => 'ids',
        'posts_per_page' => 1,
        'meta_key' => '_wp_page_template',
        'meta_value' => 'calendario-admision-template'
      ];

      $page = get_posts( $args );
      if($page):
        return $page[0];
      else:
        return false;
      endif;
    }

    static function getProximosEventosAdmision(){
      
      $args = [
        'post_type' => 'page',
        'fields' => 'ids',
        'posts_per_page' => 1,
        'meta_key' => '_wp_page_template',
        'meta_value' => 'calendario-admision-template'
      ];

      $page = get_posts( $args );
      if($page):

        
        $id_pagina_calendario = $page[0];
        $eventosArray = array();

        $anios = get_field('anios', $id_pagina_calendario);
        
        foreach ($anios as $anio):
          if($anio['fechas']):

            foreach ($anio['fechas'] as $item):

              $fecha_evento = $item['fecha_de_inicio'];
              $fecha_hoy = date('Ymd');

              if ($fecha_evento >= $fecha_hoy):
                $eventosArray[$fecha_evento] = array('titulo' => $item['titulo'], 'categoria'=>$item['categoria']);
                //echo 'El evento con fecha '.$fecha.' es una fecha futura';
              else:
                 //echo 'El evento con fecha '.$fecha.' es una fecha pasada';
              endif;

              ksort($eventosArray);
     
            endforeach;
          endif;

        endforeach;

        return $eventosArray;

      else:
        
        return false;

      endif;
    }

    static function getTemas(){
      $terms = get_terms( array(
          'taxonomy' => 'tema',
          'hide_empty' => true,
          'orderby' => 'name',
          'order' => 'ASC',
          'posts_per_page' => -1,
      ) );

      return $terms;
    }

    static function getPreguntasByTema($tema = '', $limit = -1)
    {
        $_posts = [];
        if($tema != ''){
          $posts = get_posts([
            'post_type'      => 'preguntas',
            'status'         => 'publish',
            'orderby'        => 'menu_order',
            'order'          => 'ASC',
            'posts_per_page' => $limit,
            'tax_query' => array(
                array(
                    'taxonomy' => 'tema',
                    'field'    => 'slug',
                    'terms'    => array( $tema ),
                ),
            )        
          ]);

        }else{

          $posts = get_posts([
            'post_type'      => 'preguntas',
            'status'         => 'publish',
            'orderby'        => 'menu_order',
            'order'          => 'ASC',
            'posts_per_page' => $limit,  
          ]);

        }

        foreach ($posts as $post) {
            $_posts[] = new Pregunta($post);
        }
        return $_posts;
        
    }


    static function getPreguntasConVideo($limit = -1)
    {
        $_posts = [];

        $posts = get_posts([
          'post_type'      => 'preguntas',
          'status'         => 'publish',
          'orderby'        => 'menu_order',
          'order'          => 'ASC',
          'posts_per_page' => $limit,
          'meta_query'     => array(
            array(
            'key'   => 'videorespuesta', 
            'value' => "", 
            'compare' => '!=')
          )
        ]);

        foreach ($posts as $post) {
            $_posts[] = new Pregunta($post);
        }
        return $_posts;
        
    }



    static function getSearchResults($q = '', $posts_per_page = -1, $paged)
    {
        $_posts = [];
        $posts = get_posts([
            'posts_per_page' => $posts_per_page,
            'post_type'      => array('page', 'carreras'),
            'status'         => 'publish',
            'orderby'        => 'date',
            'order'          => 'DESC',
            's'              => $q,
            'paged'          => $paged,
            'limit'          => -1
        
        ]);
        
        return $posts;
        /*foreach ($posts as $post) {

            switch ($post->post_type) {
                case 'noticias':
                    $_posts[] = new News($post);
                    break;
                case 'eventos':
                    $_posts[] = new Event($post);
                    break;
                case 'salas':
                    $_posts[] = new Room($post);
                    break;
                case 'soluciones':
                    $_posts[] = new Soluction($post);
                    break;
                case 'concursos':
                    $_posts[] = new Contest($post);
                    break;
                default:
                    $_posts[] = $post;
                    break;
            }
            
        }

        return $_posts;
        */
        
    }


    

    
    /**
     * Modification of "Build a tree from a flat array in PHP"
     *
     * Authors: @DSkinner, @ImmortalFirefly and @SteveEdson
     *
     * @link https://stackoverflow.com/a/28429487/2078474
     */
    static function buildTree(array &$elements, $parentId = 0)
    {
        $branch = [];
        foreach ($elements as &$element) {
            if ($element->menu_item_parent == $parentId) {
                $children = self::buildTree($elements, $element->ID);
                if ($children) {
                    $element->wpse_children = $children;
                }
                
                $branch[$element->ID] = $element;
                unset($element);
            }
        }
        return $branch;
    }
    
    /**
     * Transform a navigational menu to it's tree structure
     *
     * @param  String  $menud_id
     * @return Array|null $tree
     * @uses  buildTree()
     * @uses  wp_get_nav_menu_items()
     *
     */
    static function wpse_nav_menu_2_tree($menu_id)
    {
        $items = wp_get_nav_menu_items($menu_id);
        return $items ? self::buildTree($items, 0) : null;
    }
    
}
